@@ -6,34 +6,27 @@ OC.L10N.register(
     "Rename" : "إعادة التسمية",
     "Move" : "نقل",
     "Delete" : "حذف ",
+    "Select all" : "تحديد الكل",
     "New" : "جديد",
     "New folder" : "مجلد جديد",
-    "Grid view" : "عرض شبكي",
-    "List view" : "عرض على شكل قائمة",
-    "Select all" : "تحديد الكل",
     "Cancel" : "إلغاء",
     "Recent" : "الحديثة",
-    "Add a bookmark" : "إضافة فاصلة مرجعية",
     "Import" : "استيراد",
     "Export" : "تصدير",
-    "Recently added" : "اضيفت مؤخرا",
-    "Last modified" : "آخر تعديل",
     "Clear data" : "مسح البيانات",
     "Title" : "العنوان",
     "Link" : "الرابط",
     "Tags" : "الوسوم",
-    "Attachments" : "المرفقات",
     "Notes" : "الملاحظات",
     "Owner" : "المالك",
     "Sharing" : "المشاركة",
     "Share link" : "مشاركة الرابط",
     "Copy link" : "انسخ الرابط",
     "Allow editing" : "السماح بالتعديلات",
-    "Allow sharing" : "السماح بالمشاركة",
     "Link copied" : "نُسِخ الرابط",
-    "Select" : "تحديد",
-    "Previews" : "المعاينات",
     "Privacy" : "الخصوصية",
+    "Previews" : "المعاينات",
+    "Add a bookmark" : "إضافة فاصلة مرجعية",
     "Folder" : "مجلد",
     "Save" : "حفظ"
 },
