@@ -28,6 +28,8 @@ OC.L10N.register(
     "No file provided for import" : "Κανένα αρχείο για εισαγωγή",
     "Unsupported file type for import" : "Μη υποστηριζόμενος τύπος αρχείου",
     "Bookmarks shared by %s" : "Σελιδοδείκτες σε κοινή χρήση από %s",
+    "Frequent bookmarks" : "Συχνοί σελιδοδείκτες",
+    "Recent bookmarks" : "Τελευταίοι σελιδοδείκτες",
     "Bookmark" : "Σελιδοδείκτης",
     "Bookmark deleted" : "Ο σελιδοδείκτης διαγράφηκε",
     "Bookmark created" : "Ο σελιδοδείκτης δημιουργήθηκε",
@@ -52,18 +54,33 @@ OC.L10N.register(
     "Do you really want to delete these items?" : "Θέλετε πραγματικά να διαγράψετε αυτά τα στοιχεία;",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
     "_Selected %n folder_::_Selected %n folders_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
+    "Go back" : "Επιστροφή",
     "Select one or more tags" : "Επιλέξτε μία ή περισσότερες ετικέτες",
     "New" : "Νέα",
     "New bookmark" : "Νέος σελιδοδείκτης",
     "New folder" : "Νέος φάκελος",
+    "Change to grid view" : "Αλλαγή σε προβολή πλέγματος",
+    "Change to list view" : "Αλλαγή σε προβολή λίστας",
+    "Sort by created date" : "Ταξινόμηση κατά ημερομηνία δημιουργίας",
+    "Sort by last modified" : "Ταξινόμηση κατά τελευταία τροποποίηση",
+    "Sort by title" : "Ταξινόμηση κατά τίτλο",
+    "Sort by click count" : "Ταξινόμηση κατά μέτρηση κλικ",
+    "Sort by manual order" : "Ταξινόμηση κατά χειροκίνητη σειρά",
     "RSS feed copied" : "Η ροή πληροφοριών RSS αντιγράφηκε",
     "Enter a link" : "Εισάγετε σύνδεσμο",
     "Enter a title" : "Εισάγετε ένα τίτλο",
     "No bookmarks found" : "Δεν βρέθηκαν σελιδοδείκτες",
+    "{folders} folders and {bookmarks} bookmarks" : "{folders} φάκελοι και {bookmarks} σελιδοδείκτες",
+    "_%n bookmark_::_%n bookmarks_" : ["%n σελιδοδείκτης","%n σελιδοδείκτες"],
+    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
     "Select folder" : "Επιλογή φακέλου",
     "Enter folder title" : "Τίτλος φακέλου",
     "Shared by {user}" : "Διαμοιράστηκε από {user}",
+    "Rename folder" : "Μετονομασία φακέλου",
+    "Move folder" : "Μετακίνηση φακέλου",
+    "Delete folder" : "Διαγραφή φακέλου",
     "Do you really want to delete this folder?" : "Θέλετε πραγματικά να διαγράψετε αυτόν τον φάκελο;",
+    "Choose folder" : "Επιλογή φακέλου",
     "Submit" : "Υποβολή",
     "Cancel" : "Ακύρωση",
     "Deleting bookmarks" : "Γίνεται διαγραφή σελιδοδεικτών",
@@ -75,7 +92,10 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Μετακίνηση %n σελιδοδείκτη","Μετακίνηση %n σελιδοδεικτών"],
     "All bookmarks" : "Όλοι οι σελιδοδείκτες",
     "Recent" : "Πρόσφατα",
+    "Files" : "Αρχεία",
     "Broken links" : "Κατεστραμμένοι σύνδεσμοι",
+    "New tag" : "Νέα ετικέτα",
+    "Search tags" : "Ετικέτες αναζήτησης",
     "Untagged" : "Χωρίς ετικέτα",
     "{used} bookmarks of {available} available" : "Διαθέσιμοι  {available} σελιδοδείκτες από {used}",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Οι σελιδοδείκτες σε αρχεία όπως φωτογραφίες ή PDF θα αποθηκευτούν αυτόματα στα αρχεία Nextcloud, ώστε να μπορείτε να τα βρείτε ακόμα και όταν ο σύνδεσμος είναι εκτός σύνδεσης.",
@@ -87,7 +107,8 @@ OC.L10N.register(
     "Archive path" : "Διαδρομή φακέλου αρχειοθέτησης",
     "Enter the path of a folder where bookmarked files should be stored" : "Προσθέστε την διαδρομή του φακέλου όπου θα αποθηκεύονται τα αρχεία σελιδοδεικτών",
     "Client apps" : "Εφαρμογές πελάτη",
-    "Also check out the collection of client apps that integrate with this app: " : "Ελέγξτε επίσης τη συλλογή των εφαρμογών που ενσωματώνονται σε αυτήν την εφαρμογή:",
+    "Also check out the collection of client apps that integrate with this app: " : "Ελέγξτε επίσης τη συλλογή των εφαρμογών που ενσωματώνονται με αυτήν την εφαρμογή: ",
+    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Μπορείτε να εγκαταστήσετε αυτήν την εφαρμογή στην αρχική οθόνη της συσκευής σας για γρήγορη πρόσβαση στους σελιδοδείκτες σας στο τηλέφωνό σας. Μπορείτε εύκολα να αφαιρέσετε ξανά την εφαρμογή από την αρχική οθόνη, αν δεν σας αρέσει.",
     "Install on home screen" : "Εγκατάσταση στην αρχική οθόνη",
     "Bookmarklet" : "Εφαρμογίδιο Σελιδοδεικτών",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Σύρετε στους σελιδοδείκτες του περιηγητή και κάντε κλικ σε για γρήγορη αποθήκευση σελιδοδείκτη μιας ιστοσελίδας",
@@ -103,15 +124,23 @@ OC.L10N.register(
     "Select tags and create new ones" : "Επιλέξτε ετικέτες και δημιουργήστε νέες",
     "Notes" : "Σημειώσεις",
     "Notes for this bookmark …" : "Σημειώσεις για αυτό το σελιδοδείκτη …",
+    "Archived file" : "Αρχειοθετημένο αρχείο",
+    "Open file" : "Άνοιγμα αρχείου",
+    "Open file location" : "Άνοιγμα τοποθεσίας αρχείου",
+    "Created {time} ago" : "Δημιουργήθηκε πριν {time}",
+    "Created on {date}" : "Δημιουργήθηκε στις {date}",
     "Owner" : "Κάτοχος",
     "Sharing" : "Διαμοιρασμός",
     "Select a user or group" : "Επιλογή χρήστη ή ομάδας",
     "Share link" : "Διαμοιρασμός συνδέσμου",
+    "Reading allowed" : "Επιτρέπεται η ανάγνωση",
     "Copy link" : "Αντιγραφή συνδέσμου",
     "Copy RSS feed" : "Αντιγραφή ροής πληροφοριών RSS",
     "Delete link" : "Διαγραφή συνδέσμου",
     "Create public link" : "Δημιουργία δημόσιου συνδέσμου",
+    "Editing allowed" : "Επιτρέπεται η επεξεργασία",
     "Allow editing" : "Επιτρέπεται η επεξεργασία",
+    "Allow resharing" : "Επιτρέπεται ο επαναδιαμοιρασμός",
     "Remove share" : "Κατάργηση διαμοιρασμού",
     "Link copied" : "Ο σύνδεσμος αντιγράφηκε",
     "Privacy" : "Ιδιωτικότητα",
@@ -141,6 +170,7 @@ OC.L10N.register(
     "Folder" : "Φάκελος",
     "Root Folder" : "Αρχικός φάκελος",
     "Save" : "Αποθήκευση",
+    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Η πρόσβαση στο δίκτυο είναι απενεργοποιημένη από προεπιλογή. Μεταβείτε στις ρυθμίσεις διαχειριστή για την εφαρμογή σελιδοδεικτών για να επιτρέψετε την ανάκτηση προεπισκοπήσεων και favicons.",
     "Failed to count unavailable bookmarks" : "Αποτυχία μέτρησης μη διαθέσιμων σελιδοδεικτών",
     "Failed to count archived bookmarks" : "Αποτυχία μέτρησης αρχειοθετημένων σελιδοδεικτών",
     "Failed to load bookmark" : "Αποτυχία φόρτωσης σελιδοδείκτη",
