@@ -4,25 +4,21 @@ OC.L10N.register(
     "Bookmarks" : "Legosignaro",
     "No file provided for import" : "Neniu dosiero provizita por enporto",
     "Unsupported file type for import" : "Nesubtenita dosiertipo por enporto",
-    "Recent Bookmarks" : "Lastaj legosignoj",
     "A Bookmark manager for Nextcloud" : "Mastrumilo de legosignoj por Nextcloud",
     "Select bookmark" : "Elekti legosignon",
     "Details" : "Detaloj",
     "Rename" : "Alinomi",
     "Move" : "Movi",
     "Delete" : "Forigi",
-    "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
-    "New" : "Nova",
-    "New folder" : "Nova dosierujo",
-    "Grid view" : "Krada vido",
-    "List view" : "Lista vido",
     "Move selection" : "Movi elekton",
     "Delete selection" : "Forigi elekton",
     "Select all" : "Elekti ĉion",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n legosignon elektitan","%n legosignojn elektitajn"],
+    "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
+    "New" : "Nova",
+    "New folder" : "Nova dosierujo",
     "Enter a link" : "Entajpu ligilon",
     "Enter folder title" : "Entajpu titolon de la dosierujo",
-    "Root folder" : "Radika dosierujo",
     "Submit" : "Sendi",
     "Cancel" : "Nuligi",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movo de %n dosierujo kaj kelkaj legosignoj","Movo de %n dosierujoj kaj kelkaj legosignoj"],
@@ -32,14 +28,8 @@ OC.L10N.register(
     "Recent" : "Lastaj ŝanĝoj",
     "Untagged" : "Sen etikedo",
     "No bookmarks here" : "Neniu legosigno ĉi tie",
-    "Add a bookmark" : "Aldoni legosignon",
     "Import" : "Importi",
     "Export" : "Eksporti",
-    "Sorting" : "Ordigo",
-    "Recently added" : "Lastaj aldonoj",
-    "Alphabetically" : "Alfabete",
-    "Most visited" : "Plej vizititaj",
-    "Last modified" : "laŭ lasta modifo",
     "Client apps" : "Klientaj aplikaĵoj",
     "Also check out the collection of client apps that integrate with this app: " : "Ankaŭ vidu la programojn, kiuj uzas tiun aplikaĵon:",
     "Bookmarklet" : "Legosignilo",
@@ -50,11 +40,8 @@ OC.L10N.register(
     "Do you really want to delete all your bookmarks?" : "Ĉu vi ja volas forigi ĉiujn viaj legosignoj?",
     "Title" : "Titolo",
     "Link" : "Ligilo",
-    "Creation date" : "Krea dato",
     "Tags" : "Etikedoj",
-    "Attachments" : "Dosieraj aldonaĵoj",
     "Notes" : "Notoj",
-    "{time} ago" : "antaŭ {time}",
     "Owner" : "Posedanto",
     "Sharing" : "Kunhavigo",
     "Select a user or group" : "Elektu uzanton aŭ grupon",
@@ -62,19 +49,19 @@ OC.L10N.register(
     "Copy link" : "Kopii ligilon",
     "Allow editing" : "Permesi modifon",
     "Link copied" : "Ligilo kopiita",
-    "Select" : "Elekti",
-    "Previews" : "Antaŭrigardoj",
-    "Screeenly" : "Screeenly",
-    "You can either sign up for free at screeenly.com or setup your own server." : "Vi povas aŭ krei senpagan konton ĉe screeenly.com aŭ instali vian propran servilon.",
-    "Screeenly API URL" : "API-adreso de Screeenly",
-    "Screeenly API key" : "API-ŝlosilo de Screeenly",
     "Privacy" : "Privateco",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "„Legosignaro“ provos aliri retpaĝojn, kiujn vi aldonas por aldoni aŭtomate informojn pri ili.",
     "Enable accessing and collecting information from the web pages you add" : "Ebligi aliron al kaj kolekton de informoj el la retpaĝoj, kiujn vi aldonas",
     "Performance" : "Rendimento",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimuma nombro de legosignoj en unu konto. (0 por ne limigi; defaŭlte ne estas limigo)",
+    "Previews" : "Antaŭrigardoj",
+    "Screeenly" : "Screeenly",
+    "You can either sign up for free at screeenly.com or setup your own server." : "Vi povas aŭ krei senpagan konton ĉe screeenly.com aŭ instali vian propran servilon.",
+    "Screeenly API URL" : "API-adreso de Screeenly",
+    "Screeenly API key" : "API-ŝlosilo de Screeenly",
     "Failed to load settings" : "Ŝargo de agordoj malsukcesis",
     "Failed to save settings" : "Konservo de agordoj malsukcesis",
+    "Add a bookmark" : "Aldoni legosignon",
     "This URL is already bookmarked! Overwrite?" : "Tiu adreso jam ekzistas en viaj legosignoj! Anstataŭigi ĝin?",
     "Enter bookmark title" : "Entajpu titolon de la legosigno",
     "Folder" : "Dosierujo",
