@@ -15,27 +15,23 @@ OC.L10N.register(
     "Rename" : "Нэрлэнэ үү",
     "Move" : "Зөөх",
     "Delete" : "Устгах",
+    "Select all" : "бүгдийг сонгох",
     "New" : "Шинэ",
     "New folder" : "Шинэ хавтас",
-    "Select all" : "бүгдийг сонгох",
     "Submit" : "мэдэгдэх",
     "Cancel" : "болиулах",
     "Recent" : "Сүүлийн үеийн",
     "Import" : "Импорт",
     "Export" : "Экспорт",
-    "Recently added" : "Сүүлд нэмэгдсэн",
-    "Last modified" : "Сүүлд өөрчилсөн",
     "Clear data" : "Өгөгдлийг цэвэрлэх",
     "Title" : "Цол/Албан тушаал",
     "Link" : "Холбоос",
     "Tags" : "Tag-үүд",
-    "Attachments" : "Хавсралт",
     "Notes" : "Шинэ ",
     "Owner" : "Эзэмшигч",
     "Sharing" : "Түгээх",
     "Share link" : "Холбоос хуваалцах",
     "Allow editing" : "Засварлахыг зөвшөөрөх",
-    "Select" : "Сонгох",
     "Privacy" : "Хувийн нууц",
     "Folder" : "Хавтас",
     "Save" : "Хадгалах"
